@@ -374,31 +374,6 @@ rb_ary_subary(ary, beg, len)
     return ary2;
 }
 
-static VALUE
-rb_ary_subseq(ary, beg, end)
-    VALUE ary;
-    int beg, end;
-{
-    if (beg < 0) {
-	beg = RARRAY(ary)->len + beg;
-	if (beg < 0) return Qnil;
-    }
-    if (beg > RARRAY(ary)->len) {
-	if (end == -1) return rb_ary_new2(0);
-	return Qnil;
-    }
-    if (end < 0) {
-	end = RARRAY(ary)->len + end;
-	if (end < 0) return Qnil;
-    }
-
-    if (end >= RARRAY(ary)->len) {
-	end = RARRAY(ary)->len - 1;
-    }
-
-    return rb_ary_subary(ary, beg, end - beg + 1);
-}
-
 VALUE
 rb_ary_aref(argc, argv, ary)
     int argc;
@@ -406,7 +381,7 @@ rb_ary_aref(argc, argv, ary)
     VALUE ary;
 {
     VALUE arg1, arg2;
-    int beg, end, len;
+    int beg, len;
 
     if (rb_scan_args(argc, argv, "11", &arg1, &arg2) == 2) {
 	beg = NUM2INT(arg1);
@@ -424,9 +399,16 @@ rb_ary_aref(argc, argv, ary)
     else if (TYPE(arg1) == T_BIGNUM) {
 	rb_raise(rb_eIndexError, "index too big");
     }
-    else if (rb_range_beg_end(arg1, &beg, &end)) {
+    else {
 	/* check if idx is Range */
-	return rb_ary_subseq(ary, beg, end);
+	switch (rb_range_beg_len(arg1, &beg, &len, RARRAY(ary)->len, 0)) {
+	  case Qfalse:
+	    break;
+	  case Qnil:
+	    return Qnil;
+	  default:
+	    return rb_ary_subary(ary, beg, len);
+	}
     }
     return rb_ary_entry(ary, NUM2INT(arg1));
 }
@@ -535,38 +517,6 @@ rb_ary_replace(ary, beg, len, rpl)
     }
 }
 
-static int
-beg_len(range, begp, lenp, len)
-    VALUE range;
-    int *begp, *lenp;
-    int len;
-{
-    int beg, end, b, e;
-
-    if (!rb_range_beg_end(range, &beg, &end)) return Qfalse;
-    b = beg; e = end;
-    if (beg < 0) {
-	beg += len;
-	if (beg < 0) {
-	  out_of_range:
-	    rb_raise(rb_eIndexError, "range %d..%d out of array", b, e);
-	}
-    }
-    if (end < 0) {
-	end += len;
-	if (end < 0 && e != -1) goto out_of_range;
-    }
-    len = end - beg + 1;
-    if (len < 0) {
-	if (e != -1) goto out_of_range;
-	len = 0;
-    }
-    *begp = beg;
-    *lenp = len;
-
-    return Qtrue;
-}
-
 static VALUE
 rb_ary_aset(argc, argv, ary)
     int argc;
@@ -584,7 +534,7 @@ rb_ary_aset(argc, argv, ary)
 	offset = FIX2INT(arg1);
 	goto fixnum;
     }
-    else if (beg_len(arg1, &beg, &len, RARRAY(ary)->len)) {
+    else if (rb_range_beg_len(arg1, &beg, &len, RARRAY(ary)->len, 1)) {
 	/* check if idx is Range */
 	rb_ary_replace(ary, beg, len, arg2);
 	return arg2;
@@ -1082,7 +1032,7 @@ rb_ary_fill(argc, argv, ary)
 	len = RARRAY(ary)->len - beg;
 	break;
       case 2:
-	if (beg_len(arg1, &beg, &len, RARRAY(ary)->len)) {
+	if (rb_range_beg_len(arg1, &beg, &len, RARRAY(ary)->len, 1)) {
 	    break;
 	}
 	/* fall through */
