@@ -165,7 +165,7 @@ rb_int2inum(n)
 
 VALUE
 rb_str2inum(str, base)
-    char *str;
+    const char *str;
     int base;
 {
     char sign = 1, c;
