@@ -3,16 +3,16 @@
   compar.c -
 
   $Author: matz $
-  $Date: 1996/12/25 09:19:05 $
+  $Date: 1999/01/26 10:08:09 $
   created at: Thu Aug 26 14:39:48 JST 1993
 
-  Copyright (C) 1993-1996 Yukihiro Matsumoto
+  Copyright (C) 1993-1999 Yukihiro Matsumoto
 
 ************************************************/
 
 #include "ruby.h"
 
-VALUE mComparable;
+VALUE rb_mComparable;
 
 static ID cmp;
 
@@ -23,8 +23,8 @@ cmp_eq(x, y)
     VALUE c = rb_funcall(x, cmp, 1, y);
     int t = NUM2INT(c);
 
-    if (t == 0) return TRUE;
-    return FALSE;
+    if (t == 0) return Qtrue;
+    return Qfalse;
 }
 
 static VALUE
@@ -34,8 +34,8 @@ cmp_gt(x, y)
     VALUE c = rb_funcall(x, cmp, 1, y);
     int t = NUM2INT(c);
 
-    if (t > 0) return TRUE;
-    return FALSE;
+    if (t > 0) return Qtrue;
+    return Qfalse;
 }
 
 static VALUE
@@ -45,8 +45,8 @@ cmp_ge(x, y)
     VALUE c = rb_funcall(x, cmp, 1, y);
     int t = NUM2INT(c);
 
-    if (t >= 0) return TRUE;
-    return FALSE;
+    if (t >= 0) return Qtrue;
+    return Qfalse;
 }
 
 static VALUE
@@ -56,8 +56,8 @@ cmp_lt(x, y)
     VALUE c = rb_funcall(x, cmp, 1, y);
     int t = NUM2INT(c);
 
-    if (t < 0) return TRUE;
-    return FALSE;
+    if (t < 0) return Qtrue;
+    return Qfalse;
 }
 
 static VALUE
@@ -67,8 +67,8 @@ cmp_le(x, y)
     VALUE c = rb_funcall(x, cmp, 1, y);
     int t = NUM2INT(c);
 
-    if (t <= 0) return TRUE;
-    return FALSE;
+    if (t <= 0) return Qtrue;
+    return Qfalse;
 }
 
 static VALUE
@@ -76,25 +76,25 @@ cmp_between(x, min, max)
     VALUE x, min, max;
 {
     VALUE c = rb_funcall(x, cmp, 1, min);
-    int t = NUM2INT(c);
-    if (t < 0) return FALSE;
+    long t = NUM2LONG(c);
+    if (t < 0) return Qfalse;
 
     c = rb_funcall(x, cmp, 1, max);
-    t = NUM2INT(c);
-    if (t > 0) return FALSE;
-    return TRUE;
+    t = NUM2LONG(c);
+    if (t > 0) return Qfalse;
+    return Qtrue;
 }
 
 void
 Init_Comparable()
 {
-    mComparable = rb_define_module("Comparable");
-    rb_define_method(mComparable, "==", cmp_eq, 1);
-    rb_define_method(mComparable, ">", cmp_gt, 1);
-    rb_define_method(mComparable, ">=", cmp_ge, 1);
-    rb_define_method(mComparable, "<", cmp_lt, 1);
-    rb_define_method(mComparable, "<=", cmp_le, 1);
-    rb_define_method(mComparable, "between?", cmp_between, 2);
+    rb_mComparable = rb_define_module("Comparable");
+    rb_define_method(rb_mComparable, "==", cmp_eq, 1);
+    rb_define_method(rb_mComparable, ">", cmp_gt, 1);
+    rb_define_method(rb_mComparable, ">=", cmp_ge, 1);
+    rb_define_method(rb_mComparable, "<", cmp_lt, 1);
+    rb_define_method(rb_mComparable, "<=", cmp_le, 1);
+    rb_define_method(rb_mComparable, "between?", cmp_between, 2);
 
     cmp = rb_intern("<=>");
 }
