@@ -3,7 +3,7 @@
   defines.h -
 
   $Author: matz $
-  $Date: 1996/12/25 10:42:25 $
+  $Date: 1999/01/26 10:08:10 $
   created at: Wed May 18 00:21:44 JST 1994
 
 ************************************************/
@@ -12,24 +12,30 @@
 
 #define RUBY
 
-/* define EUC/SJIS for default kanji-code */
-#if defined(MSDOS) || defined(__CYGWIN32__) || defined(__human68k__)
-#undef EUC
-#define SJIS
+/* define RUBY_USE_EUC/SJIS for default kanji-code */
+#if defined(MSDOS) || defined(__CYGWIN32__) || defined(__human68k__) || defined(__MACOS__)
+#undef RUBY_USE_EUC
+#define RUBY_USE_SJIS
 #else
-#define EUC
-#undef SJIS
+#define RUBY_USE_EUC
+#undef RUBY_USE_SJIS
 #endif
 
 #ifdef NeXT
 #define DYNAMIC_ENDIAN		/* determine endian at runtime */
+#ifndef __APPLE__
 #define S_IXUSR _S_IXUSR        /* execute/search permission, owner */
+#endif
 #define S_IXGRP 0000010         /* execute/search permission, group */
 #define S_IXOTH 0000001         /* execute/search permission, other */
 #endif /* NeXT */
 
 #ifdef NT
-#include "missing/nt.h"
+#include "win32/win32.h"
+#endif
+
+#ifndef EXTERN
+#define EXTERN extern
 #endif
 
 #ifdef sparc
@@ -38,7 +44,13 @@
 #define FLUSH_REGISTER_WINDOWS /* empty */
 #endif
 
-#ifdef __human68k__
+#if defined(MSDOS) || defined(NT) || defined(__human68k__)
+#define RUBY_PATH_SEP ";"
+#else
+#define RUBY_PATH_SEP ":"
+#endif
+
+#if defined(__human68k__) || defined(__CYGWIN32__)
 #undef HAVE_RANDOM
 #undef HAVE_SETITIMER
 #endif
