@@ -19,12 +19,12 @@
 #endif
 #endif
 
-char *dln_find_exe _((char*,char*));
-char *dln_find_file _((char*,char*));
+char *dln_find_exe _((const char*,const char*));
+char *dln_find_file _((const char*,const char*));
 
 #ifdef USE_DLN_A_OUT
 extern char *dln_argv0;
 #endif
 
-void dln_load _((char*));
+void dln_load _((const char*));
 #endif
