@@ -583,15 +583,15 @@ class TkFont
 
   def kanji_replace_core_tk81(knj)
     if font.kind_of? Hash
-      tk_call('font', 'configure', @compoundfont, *hash_kv(font))
+      tk_call('font', 'configure', @compoundfont, *hash_kv(knj))
     else
       keys = {}
-      if font.kind_of? Array
-	actual_core(array2tk_list(font)).each{|key,val| keys[key] = val}
-      elsif font.kind_of? TkFont
-	actual_core(font.latin_font).each{|key,val| keys[key] = val}
+      if knj.kind_of? Array
+	actual_core(array2tk_list(knj)).each{|key,val| keys[key] = val}
+      elsif knj.kind_of? TkFont
+	actual_core(knj.latin_font).each{|key,val| keys[key] = val}
       else
-	actual_core(font).each{|key,val| keys[key] = val}
+	actual_core(knj).each{|key,val| keys[key] = val}
       end
       tk_call('font', 'configure', @compoundfont, *hash_kv(keys))
     end
