@@ -56,9 +56,7 @@ rb_call_inits()
     Init_eval();
     Init_String();
     Init_Exception();
-#ifdef USE_THREAD
     Init_Thread();
-#endif
     Init_Numeric();
     Init_Bignum();
     Init_Array();
