@@ -41,7 +41,7 @@ VALUE rb_uint2big _((unsigned long));
 VALUE rb_int2big _((long));
 VALUE rb_uint2inum _((unsigned long));
 VALUE rb_int2inum _((long));
-VALUE rb_str2inum _((char*, int));
+VALUE rb_str2inum _((const char*, int));
 VALUE rb_big2str _((VALUE, int));
 long rb_big2long _((VALUE));
 #define rb_big2int(x) rb_big2long(x)
@@ -73,28 +73,28 @@ VALUE rb_class_protected_instance_methods _((int, VALUE*, VALUE));
 VALUE rb_class_private_instance_methods _((int, VALUE*, VALUE));
 VALUE rb_obj_singleton_methods _((VALUE));
 void rb_define_method_id _((VALUE, ID, VALUE (*)(), int));
-void rb_undef_method _((VALUE, char*));
-void rb_define_protected_method _((VALUE, char*, VALUE (*)(), int));
-void rb_define_private_method _((VALUE, char*, VALUE (*)(), int));
-void rb_define_singleton_method _((VALUE,char*,VALUE(*)(),int));
-void rb_define_private_method _((VALUE,char*,VALUE(*)(),int));
+void rb_undef_method _((VALUE, const char*));
+void rb_define_protected_method _((VALUE, const char*, VALUE (*)(), int));
+void rb_define_private_method _((VALUE, const char*, VALUE (*)(), int));
+void rb_define_singleton_method _((VALUE,const char*,VALUE(*)(),int));
+void rb_define_private_method _((VALUE,const char*,VALUE(*)(),int));
 VALUE rb_singleton_class _((VALUE));
 /* enum.c */
 VALUE rb_enum_length _((VALUE));
 /* error.c */
 extern int ruby_nerrs;
-VALUE rb_exc_new _((VALUE, char*, int));
-VALUE rb_exc_new2 _((VALUE, char*));
+VALUE rb_exc_new _((VALUE, const char*, int));
+VALUE rb_exc_new2 _((VALUE, const char*));
 VALUE rb_exc_new3 _((VALUE, VALUE));
-void rb_loaderror __((char*, ...)) NORETURN;
-void rb_compile_error __((char*, ...));
-void rb_compile_error_append __((char*, ...));
+void rb_loaderror __((const char*, ...)) NORETURN;
+void rb_compile_error __((const char*, ...));
+void rb_compile_error_append __((const char*, ...));
 /* eval.c */
 void rb_exc_raise _((VALUE)) NORETURN;
 void rb_exc_fatal _((VALUE)) NORETURN;
-void rb_remove_method _((VALUE, char*));
-void rb_disable_super _((VALUE, char*));
-void rb_enable_super _((VALUE, char*));
+void rb_remove_method _((VALUE, const char*));
+void rb_disable_super _((VALUE, const char*));
+void rb_enable_super _((VALUE, const char*));
 void rb_clear_cache _((void));
 void rb_alias _((VALUE, ID, ID));
 void rb_attr _((VALUE,ID,int,int,int));
@@ -115,7 +115,7 @@ VALUE rb_obj_instance_eval _((int, VALUE*, VALUE));
 void rb_load _((VALUE, int));
 void rb_load_protect _((VALUE, int, int*));
 void rb_jump_tag _((int)) NORETURN;
-void rb_provide _((char*));
+void rb_provide _((const char*));
 VALUE rb_f_require _((VALUE, VALUE));
 void rb_obj_call_init _((VALUE, int, VALUE*));
 VALUE rb_class_new_instance _((int, VALUE*, VALUE));
@@ -142,9 +142,9 @@ VALUE rb_thread_main _((void));
 VALUE rb_thread_local_aref _((VALUE, ID));
 VALUE rb_thread_local_aset _((VALUE, ID, VALUE));
 /* file.c */
-int eaccess _((char*, int));
+int eaccess _((const char*, int));
 VALUE rb_file_s_expand_path _((int, VALUE *));
-void rb_file_const _((char*, VALUE));
+void rb_file_const _((const char*, VALUE));
 /* gc.c */
 void rb_global_variable _((VALUE*));
 void rb_gc_mark_locations _((VALUE*, VALUE*));
@@ -176,7 +176,7 @@ VALUE rb_io_ungetc _((VALUE, VALUE));
 VALUE rb_io_close _((VALUE));
 VALUE rb_io_eof _((VALUE));
 VALUE rb_io_binmode _((VALUE));
-VALUE rb_file_open _((char*, char*));
+VALUE rb_file_open _((const char*, const char*));
 VALUE rb_gets _((void));
 void rb_str_setter _((VALUE, ID, VALUE*));
 /* numeric.c */
@@ -198,7 +198,7 @@ VALUE rb_obj_taint _((VALUE));
 VALUE rb_obj_tainted _((VALUE));
 VALUE rb_obj_untaint _((VALUE));
 VALUE rb_obj_id _((VALUE));
-VALUE rb_convert_type _((VALUE,int,char*,char*));
+VALUE rb_convert_type _((VALUE,int,const char*,const char*));
 VALUE rb_Integer _((VALUE));
 VALUE rb_Float _((VALUE));
 VALUE rb_String _((VALUE));
@@ -217,11 +217,11 @@ void rb_backref_set _((VALUE));
 VALUE rb_lastline_get _((void));
 void rb_lastline_set _((VALUE));
 /* process.c */
-int rb_proc_exec _((char*));
+int rb_proc_exec _((const char*));
 void rb_syswait _((int));
 /* range.c */
-VALUE rb_range_new _((VALUE, VALUE));
-VALUE rb_range_beg_end _((VALUE, int*, int*));
+VALUE rb_range_new _((VALUE, VALUE, int));
+VALUE rb_range_beg_len _((VALUE, int*, int*, int, int));
 /* re.c */
 VALUE rb_reg_nth_defined _((int, VALUE));
 VALUE rb_reg_nth_match _((int, VALUE));
@@ -229,12 +229,12 @@ VALUE rb_reg_last_match _((VALUE));
 VALUE rb_reg_match_pre _((VALUE));
 VALUE rb_reg_match_post _((VALUE));
 VALUE rb_reg_match_last _((VALUE));
-VALUE rb_reg_new _((char*, int, int));
+VALUE rb_reg_new _((const char*, int, int));
 VALUE rb_reg_match _((VALUE, VALUE));
 VALUE rb_reg_match2 _((VALUE));
 int rb_reg_options _((VALUE));
-char*rb_get_kcode _((void));
-void rb_set_kcode _((char*));
+const char* rb_get_kcode _((void));
+void rb_set_kcode _((const char*));
 int rb_ignorecase_p _((void));
 /* ruby.c */
 extern VALUE rb_argv0;
@@ -257,12 +257,12 @@ void rb_trap_exec _((void));
 /* sprintf.c */
 VALUE rb_f_sprintf _((int, VALUE*));
 /* string.c */
-VALUE rb_str_new _((char*, int));
-VALUE rb_str_new2 _((char*));
+VALUE rb_str_new _((const char*, int));
+VALUE rb_str_new2 _((const char*));
 VALUE rb_str_new3 _((VALUE));
 VALUE rb_str_new4 _((VALUE));
-VALUE rb_tainted_str_new _((char*, int));
-VALUE rb_tainted_str_new2 _((char*));
+VALUE rb_tainted_str_new _((const char*, int));
+VALUE rb_tainted_str_new2 _((const char*));
 VALUE rb_obj_as_string _((VALUE));
 VALUE rb_str_to_str _((VALUE));
 VALUE rb_str_dup _((VALUE));
@@ -272,32 +272,34 @@ VALUE rb_str_substr _((VALUE, int, int));
 void rb_str_modify _((VALUE));
 VALUE rb_str_freeze _((VALUE));
 VALUE rb_str_resize _((VALUE, int));
-VALUE rb_str_cat _((VALUE, char*, int));
+VALUE rb_str_cat _((VALUE, const char*, int));
 VALUE rb_str_concat _((VALUE, VALUE));
 int rb_str_hash _((VALUE));
 int rb_str_cmp _((VALUE, VALUE));
-VALUE rb_str_upto _((VALUE, VALUE));
+VALUE rb_str_upto _((VALUE, VALUE, int));
 VALUE rb_str_inspect _((VALUE));
-VALUE rb_str_split _((VALUE, char*));
+VALUE rb_str_split _((VALUE, const char*));
 /* struct.c */
 VALUE rb_struct_new __((VALUE, ...));
-VALUE rb_struct_define __((char*, ...));
+VALUE rb_struct_define __((const char*, ...));
 VALUE rb_struct_alloc _((VALUE, VALUE));
 VALUE rb_struct_aref _((VALUE, VALUE));
 VALUE rb_struct_aset _((VALUE, VALUE, VALUE));
 VALUE rb_struct_getmember _((VALUE, ID));
+/* time.c */
+VALUE rb_time_new();
 /* variable.c */
 VALUE rb_mod_name _((VALUE));
 VALUE rb_class_path _((VALUE));
-void rb_set_class_path _((VALUE, VALUE, char*));
-VALUE rb_path2class _((char*));
+void rb_set_class_path _((VALUE, VALUE, const char*));
+VALUE rb_path2class _((const char*));
 void rb_name_class _((VALUE, ID));
-void rb_autoload _((char*, char*));
+void rb_autoload _((const char*, const char*));
 VALUE rb_f_autoload _((VALUE, VALUE, VALUE));
 void rb_gc_mark_global_tbl _((void));
 VALUE rb_f_trace_var _((int, VALUE*));
 VALUE rb_f_untrace_var _((int, VALUE*));
-VALUE rb_gvar_set2 _((char*, VALUE));
+VALUE rb_gvar_set2 _((const char*, VALUE));
 VALUE rb_f_global_variables _((void));
 void rb_alias_variable _((ID, ID));
 void rb_mark_generic_ivar _((VALUE));
