@@ -1154,8 +1154,8 @@ rb_open(fname, flag, mode)
 
 FILE *
 rb_fopen(fname, mode)
-    char *fname;
-    char *mode;
+    const char *fname;
+    const char *mode;
 {
     FILE *file;
 
@@ -1175,7 +1175,7 @@ rb_fopen(fname, mode)
 FILE *
 rb_fdopen(fd, mode)
     int fd;
-    char *mode;
+    const char *mode;
 {
     FILE *file;
 
@@ -1194,7 +1194,7 @@ rb_fdopen(fd, mode)
 
 VALUE
 rb_file_open(fname, mode)
-    char *fname, *mode;
+    const char *fname, *mode;
 {
     OpenFile *fptr;
     NEWOBJ(port, struct RFile);
@@ -1384,8 +1384,6 @@ pipe_open(pname, mode)
 	}
 
 	if (doexec) {
-	    extern char *ruby_sourcefile;
-	    extern int   ruby_sourceline;
 	    int fd;
 
 	    for (fd = 3; fd < NOFILE; fd++)
