@@ -29,23 +29,23 @@ class Delegator
     end
     for method in obj.methods
       next if preserved.include? method
-      eval <<EOS
-def self.#{method}(*args, &block)
-  begin
-    __getobj__.__send__(:#{method}, *args, &block)
-  rescue Exception
-    c = -caller(0).size
-    if /:in `__getobj__'$/ =~ $@[c-1]  #`
-      n = 1
-    else
-      c -= 2
-      n = 3
-    end
-    $@[c,n] = nil
-    raise
-  end
-end
-EOS
+      eval <<-EOS
+	def self.#{method}(*args, &block)
+	  begin
+	    __getobj__.__send__(:#{method}, *args, &block)
+	  rescue Exception
+	    c = -caller(0).size
+	    if /:in `__getobj__'$/ =~ $@[c-1]  #`
+	      n = 1
+	    else
+	      c -= 1
+	      n = 2
+	    end
+	    $@[c,n] = nil
+	    raise
+	  end
+	end
+	EOS
     end
   end
 
@@ -81,25 +81,25 @@ def DelegateClass(superclass)
   methods = superclass.instance_methods
   methods -= ::Kernel.instance_methods
   methods |= ["to_s","to_a","inspect","==","=~","==="]
-  klass.module_eval <<EOS
+  klass.module_eval <<-EOS
   def initialize(obj)
     @obj = obj
   end
-EOS
+  EOS
   for method in methods
-    klass.module_eval <<EOS
-    def #{method}(*args, &block)
-      begin
-	@obj.__send__(:#{method}, *args, &block)
-      rescue
-	$@[0,2] = nil
-	raise
+    klass.module_eval <<-EOS
+	def #{method}(*args, &block)
+	  begin
+	    @obj.__send__(:#{method}, *args, &block)
+	  rescue
+	    $@[0,2] = nil
+	    raise
+	  end
+	end
+	EOS
       end
-    end
-EOS
+    return klass;
   end
-  return klass;
-end
 
 if __FILE__ == $0
   class ExtArray<DelegateClass(Array)
@@ -115,10 +115,12 @@ if __FILE__ == $0
 
   foo = Object.new
   def foo.test
+    25
+  end
+  def foo.error
     raise 'this is OK'
   end
   foo2 = SimpleDelegator.new(foo)
-  p foo.hash == foo2.hash	# => true
-  foo.test			# raise error!
-
+  p foo.test == foo2.test	# => true
+  foo2.error			# raise error!
 end
