@@ -331,9 +331,9 @@ VALUE rb_method_booundp();
 #define NOEX_PRIVATE   2
 #define NOEX_PROTECTED 4 
 
-NODE *rb_compile_cstr _((char *, char *, int));
-NODE *rb_compile_string _((char *, VALUE));
-NODE *rb_compile_file _((char *, VALUE, int));
+NODE *rb_compile_cstr _((const char*, const char*, int));
+NODE *rb_compile_string _((const char*, VALUE));
+NODE *rb_compile_file _((const char*, VALUE, int));
 
 void rb_add_method _((VALUE, ID, NODE *, int));
 NODE *rb_node_newnode();
