@@ -308,10 +308,11 @@ proc_exec_n(argc, argv, progv)
 
 int
 rb_proc_exec(str)
-    char *str;
+    const char *str;
 {
 #ifndef USE_CWGUSI
-    char *s = str, *t;
+    const char *s = str;
+    char *ss, *t;
     char **argv, **a;
 
     security(str);
@@ -346,9 +347,9 @@ rb_proc_exec(str)
 	}
     }
     a = argv = ALLOCA_N(char*, (s-str)/2+2);
-    s = ALLOCA_N(char, s-str+1);
-    strcpy(s, str);
-    if (*a++ = strtok(s, " \t")) {
+    ss = ALLOCA_N(char, s-str+1);
+    strcpy(ss, str);
+    if (*a++ = strtok(ss, " \t")) {
 	while (t = strtok(NULL, " \t")) {
 	    *a++ = t;
 	}
