@@ -151,22 +151,22 @@ typedef struct
 
 #ifdef __STDC__
 
-extern char *re_compile_pattern (char *, int, struct re_pattern_buffer *);
+extern char *re_compile_pattern (const char *, int, struct re_pattern_buffer *);
 void re_free_pattern (struct re_pattern_buffer *);
 /* Is this really advertised?  */
 extern void re_compile_fastmap (struct re_pattern_buffer *);
-extern int re_search (struct re_pattern_buffer *, char*, int, int, int,
+extern int re_search (struct re_pattern_buffer *, const char*, int, int, int,
 		      struct re_registers *);
-extern int re_match (struct re_pattern_buffer *, char *, int, int,
+extern int re_match (struct re_pattern_buffer *, const char *, int, int,
 		     struct re_registers *);
-extern void re_set_casetable (char *table);
+extern void re_set_casetable (const char *table);
 extern void re_copy_registers (struct re_registers*, struct re_registers*);
 extern void re_free_registers (struct re_registers*);
 
 #ifndef RUBY
 /* 4.2 bsd compatibility.  */
-extern char *re_comp (char *);
-extern int re_exec (char *);
+extern char *re_comp (const char *);
+extern int re_exec (const char *);
 #endif
 
 #else /* !__STDC__ */
