@@ -34,9 +34,9 @@
 #endif
 
 #ifndef HAVE_STRING_H
-char *strchr _((char*,char));
-char *strrchr _((char*,char));
-char *strstr _((char*,char*));
+char *strchr _((const char*,const char));
+char *strrchr _((const char*,const char));
+char *strstr _((const char*,const char*));
 #endif
 
 #include "util.h"
@@ -61,7 +61,7 @@ static int xflag = Qfalse;
 
 static void load_stdin _((void));
 static void load_file _((char *, int));
-static void forbid_setid _((char *));
+static void forbid_setid _((const char *));
 
 static VALUE do_loop = Qfalse, do_print = Qfalse;
 static VALUE do_check = Qfalse, do_line = Qfalse;
@@ -74,7 +74,7 @@ static char **origargv;
 
 static void
 usage(name)
-    char *name;
+    const char *name;
 {
     /* This message really ought to be max 23 lines.
      * Removed -h because the user already knows that opton. Others? */
@@ -126,7 +126,7 @@ static char *e_tmpname;
 
 static void
 addpath(path)
-    char *path;
+    const char *path;
 {
     const char sep = RUBY_PATH_SEP[0];
 
@@ -139,7 +139,7 @@ addpath(path)
     }
 #endif
     if (strchr(path, sep)) {
-	char *p, *s;
+	const char *p, *s;
 	VALUE ary = rb_ary_new();
 
 	p = path;
@@ -162,14 +162,14 @@ addpath(path)
 }
 
 struct req_list {
-    char *name;
+    const char *name;
     struct req_list *next;
 } req_list_head;
 struct req_list *req_list_last = &req_list_head;
 
 static void
 add_modules(mod)
-    char *mod;
+    const char *mod;
 {
     struct req_list *list;
 
@@ -735,7 +735,7 @@ init_ids()
 
 static void
 forbid_setid(s)
-    char *s;
+    const char *s;
 {
     if (euid != uid)
         rb_raise(rb_eSecurityError, "No %s allowed while running setuid", s);
