@@ -35,7 +35,7 @@ extern VALUE rb_rs;
 
 VALUE
 rb_str_new(ptr, len)
-    char *ptr;
+    const char *ptr;
     int len;
 {
     NEWOBJ(str, struct RString);
@@ -54,14 +54,14 @@ rb_str_new(ptr, len)
 
 VALUE
 rb_str_new2(ptr)
-    char *ptr;
+    const char *ptr;
 {
     return rb_str_new(ptr, strlen(ptr));
 }
 
 VALUE
 rb_tainted_str_new(ptr, len)
-    char *ptr;
+    const char *ptr;
     int len;
 {
     VALUE str = rb_str_new(ptr, len);
@@ -72,7 +72,7 @@ rb_tainted_str_new(ptr, len)
 
 VALUE
 rb_tainted_str_new2(ptr)
-    char *ptr;
+    const char *ptr;
 {
     VALUE str = rb_str_new2(ptr);
 
@@ -326,62 +326,37 @@ rb_str_substr(str, beg, len)
     return str2;
 }
 
-static VALUE
-rb_str_subseq(str, beg, end)
+void
+rb_str_modify(str)
     VALUE str;
-    int beg, end;
 {
-    if (beg < 0) {
-	beg = RSTRING(str)->len + beg;
-	if (beg < 0) return Qnil;
+    char *ptr;
+
+    if (FL_TEST(str, STR_FREEZE))
+	rb_raise(rb_eTypeError, "can't modify frozen string");
+    if (!FL_TEST(str, FL_TAINT) && rb_safe_level() >= 4)
+	rb_raise(rb_eSecurityError, "Insecure: can't modify string");
+    if (!RSTRING(str)->orig || FL_TEST(str, STR_NO_ORIG)) return;
+    ptr = RSTRING(str)->ptr;
+    RSTRING(str)->ptr = ALLOC_N(char, RSTRING(str)->len+1);
+    if (RSTRING(str)->ptr) {
+	memcpy(RSTRING(str)->ptr, ptr, RSTRING(str)->len);
+	RSTRING(str)->ptr[RSTRING(str)->len] = 0;
     }
-    if (beg > RSTRING(str)->len) {
-	return Qnil;
-    }
-    if (end < 0) {
-	if (end == -1 && RSTRING(str)->len == 0) {
-	    return rb_str_new(0, 0);
-	}
-	end = RSTRING(str)->len + end;
-    }
-     if (end >= RSTRING(str)->len) {
-	 end = RSTRING(str)->len - 1;
-     }
+    RSTRING(str)->orig = 0;
+}
 
-     return rb_str_substr(str, beg, end - beg + 1);
- }
+VALUE
+rb_str_freeze(str)
+    VALUE str;
+{
+    FL_SET(str, STR_FREEZE);
+    return str;
+}
 
- void
- rb_str_modify(str)
-     VALUE str;
- {
-     char *ptr;
-
-     if (FL_TEST(str, STR_FREEZE))
-	 rb_raise(rb_eTypeError, "can't modify frozen string");
-     if (!FL_TEST(str, FL_TAINT) && rb_safe_level() >= 4)
-	 rb_raise(rb_eSecurityError, "Insecure: can't modify string");
-     if (!RSTRING(str)->orig || FL_TEST(str, STR_NO_ORIG)) return;
-     ptr = RSTRING(str)->ptr;
-     RSTRING(str)->ptr = ALLOC_N(char, RSTRING(str)->len+1);
-     if (RSTRING(str)->ptr) {
-	 memcpy(RSTRING(str)->ptr, ptr, RSTRING(str)->len);
-	 RSTRING(str)->ptr[RSTRING(str)->len] = 0;
-     }
-     RSTRING(str)->orig = 0;
- }
-
- VALUE
- rb_str_freeze(str)
-     VALUE str;
- {
-     FL_SET(str, STR_FREEZE);
-     return str;
- }
-
- static VALUE
- rb_str_frozen_p(str)
-     VALUE str;
+static VALUE
+rb_str_frozen_p(str)
+    VALUE str;
 {
     if (FL_TEST(str, STR_FREEZE))
 	return Qtrue;
@@ -420,7 +395,7 @@ rb_str_resize(str, len)
 VALUE
 rb_str_cat(str, ptr, len)
     VALUE str;
-    char *ptr;
+    const char *ptr;
     int len;
 {
     if (len > 0) {
@@ -568,10 +543,15 @@ rb_str_index(str, sub, offset)
     char *s, *e, *p;
     int len;
 
+    if (offset < 0) {
+	offset += RSTRING(str)->len;
+	if (offset < 0) return -1;
+    }
     if (RSTRING(str)->len - offset < RSTRING(sub)->len) return -1;
     s = RSTRING(str)->ptr+offset;
     p = RSTRING(sub)->ptr;
     len = RSTRING(sub)->len;
+    if (len == 0) return offset;
     e = RSTRING(str)->ptr + RSTRING(str)->len - len + 1;
     while (s < e) {
 	if (*s == *(RSTRING(sub)->ptr) && memcmp(s, p, len) == 0) {
@@ -757,8 +737,9 @@ rb_str_succ_bang(str)
 }
 
 VALUE
-rb_str_upto(beg, end)
+rb_str_upto(beg, end, excl)
     VALUE beg, end;
+    int excl;
 {
     VALUE current;
 
@@ -767,8 +748,9 @@ rb_str_upto(beg, end)
     current = beg;
     for (;;) {
 	rb_yield(current);
-	if (rb_str_equal(current, end)) break;
+	if (!excl && rb_str_equal(current, end)) break;
 	current = rb_str_succ(current);
+	if (excl && rb_str_equal(current, end)) break;
 	if (RSTRING(current)->len > RSTRING(end)->len)
 	    break;
     }
@@ -776,6 +758,13 @@ rb_str_upto(beg, end)
     return Qnil;
 }
 
+static VALUE
+rb_str_upto_method(beg, end)
+    VALUE beg, end;
+{
+    return rb_str_upto(beg, end, 0);
+}
+
 static VALUE
 rb_str_aref(str, indx)
     VALUE str;
@@ -807,9 +796,14 @@ rb_str_aref(str, indx)
       default:
 	/* check if indx is Range */
 	{
-	    int beg, end;
-	    if (rb_range_beg_end(indx, &beg, &end)) {
-		return rb_str_subseq(str, beg, end);
+	    int beg, len;
+	    switch (rb_range_beg_len(indx, &beg, &len, RSTRING(str)->len, 0)) {
+	      case Qfalse:
+		break;
+	      case Qnil:
+		return Qnil;
+	      default:
+		return rb_str_substr(str, beg, len);
 	    }
 	}
 	rb_raise(rb_eIndexError, "invalid index for string");
@@ -855,38 +849,6 @@ rb_str_replace(str, beg, len, val)
     RSTRING(str)->ptr[RSTRING(str)->len] = '\0';
 }
 
-/* rb_str_replace2() understands negative offset */
-static void
-rb_str_replace2(str, beg, end, val)
-    VALUE str, val;
-    int beg, end;
-{
-    int b, e, len;
-
-    b = beg; e = end;
-    if (beg < 0) {
-	beg += RSTRING(str)->len;
-	if (beg < 0) {
-	  out_of_range:
-	    rb_raise(rb_eIndexError, "range %d..%d out of string", b, e);
-	}
-    }
-    if (end < 0) {
-	end += RSTRING(str)->len;
-	if (end < -1 || (end == -1 && RSTRING(str)->len != 0)) {
-	    goto out_of_range;
-	}
-    }
-    if (end - beg + 1 < 0) goto out_of_range;
-    len = end - beg + 1;
-    if (len < 0) goto out_of_range;
-    if (beg + len >= RSTRING(str)->len) {
-	len = RSTRING(str)->len - beg;
-    }
-    rb_str_replace(str, beg, len, val);
-    return;
-}
-
 static VALUE rb_str_sub_bang _((int, VALUE*, VALUE));
 
 static VALUE
@@ -940,9 +902,9 @@ rb_str_aset(str, indx, val)
       default:
 	/* check if indx is Range */
 	{
-	    int beg, end;
-	    if (rb_range_beg_end(indx, &beg, &end)) {
-		rb_str_replace2(str, beg, end, val);
+	    int beg, len;
+	    if (rb_range_beg_len(indx, &beg, &len, RSTRING(str)->len, 2)) {
+		rb_str_replace(str, beg, len, val);
 		return val;
 	    }
 	}
@@ -2072,14 +2034,14 @@ rb_str_split_method(argc, argv, str)
 		if (BEG(idx) == END(idx))
 		    tmp = rb_str_new(0, 0);
 		else
-		    tmp = rb_str_subseq(str, BEG(idx), END(idx)-1);
+		    tmp = rb_str_substr(str, BEG(idx), END(idx)-BEG(idx));
 		rb_ary_push(result, tmp);
 	    }
 	    if (!NIL_P(limit) && lim <= ++i) break;
 	}
     }
     if (!NIL_P(limit) || RSTRING(str)->len > beg || lim < 0) {
-	rb_ary_push(result, rb_str_subseq(str, beg, -1));
+	rb_ary_push(result, rb_str_substr(str, beg, RSTRING(str)->len-beg));
     }
     if (NIL_P(limit) && lim == 0) {
 	while (RARRAY(result)->len > 0 &&
@@ -2093,7 +2055,7 @@ rb_str_split_method(argc, argv, str)
 VALUE
 rb_str_split(str, sep0)
     VALUE str;
-    char *sep0;
+    const char *sep0;
 {
     VALUE sep;
 
@@ -2582,7 +2544,7 @@ Init_String()
     rb_define_method(rb_cString, "succ!", rb_str_succ_bang, 0);
     rb_define_method(rb_cString, "next", rb_str_succ, 0);
     rb_define_method(rb_cString, "next!", rb_str_succ_bang, 0);
-    rb_define_method(rb_cString, "upto", rb_str_upto, 1);
+    rb_define_method(rb_cString, "upto", rb_str_upto_method, 1);
     rb_define_method(rb_cString, "index", rb_str_index_method, -1);
     rb_define_method(rb_cString, "rindex", rb_str_rindex, -1);
     rb_define_method(rb_cString, "replace", rb_str_replace_method, 1);
