@@ -21,9 +21,9 @@
 #endif
 
 #define scan_oct ruby_scan_oct
-unsigned long scan_oct _((char*, int, int*));
+unsigned long scan_oct _((const char*, int, int*));
 #define scan_hex ruby_scan_hex
-unsigned long scan_hex _((char*, int, int*));
+unsigned long scan_hex _((const char*, int, int*));
 
 #if defined(MSDOS) || defined(__CYGWIN32__) || defined(NT)
 void ruby_add_suffix();
